package com.uas.ps.message;

import com.uas.ps.core.util.ContextUtils;
import com.uas.sso.web.AccountConfigurer;
import org.springframework.boot.SpringApplication;
import org.springframework.boot.autoconfigure.SpringBootApplication;
import org.springframework.boot.context.event.ApplicationPreparedEvent;
import org.springframework.context.ApplicationListener;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Profile;
import org.springframework.web.servlet.config.annotation.EnableWebMvc;

import java.io.*;
import java.util.Properties;
import java.util.logging.Logger;


/**
 * 应用入口
 *
 * @author sunyj
 * @since 2017年8月16日 下午4:00:03
 */
@SpringBootApplication
@EnableWebMvc
//@EnableSSO
public class Application {

    private static final Logger logger = Logger.getLogger(org.apache.log4j.Logger.class.getName());

    public static void main(String[] args) throws FileNotFoundException {
        File logFile = new File("logs/log.log");
        if (!logFile.getParentFile().exists()) {
            logFile.getParentFile().mkdir();
        }
        System.setErr(new PrintStream(new FileOutputStream(logFile, true)));
        SpringApplication application = new SpringApplication(Application.class);
        application.addListeners(new ApplicationListener<ApplicationPreparedEvent>() {
            @Override
            public void onApplicationEvent(ApplicationPreparedEvent event) {
                ContextUtils.setApplicationContext(event.getApplicationContext());
            }
        });
        application.run(args);
    }

    @Bean(name = "accountConfigurer")
    @Profile(value = {"test", "dev"})
    public AccountConfigurer devAccountConfigurer() {
        return accountConfigurer("dev");
    }

    @Bean(name = "accountConfigurer")
    @Profile(value = {"prod"})
    public AccountConfigurer prodAccountConfigurer() {
        return accountConfigurer("prod");
    }

    /**
     * 获取当前环境下的配置
     * @param profile
     * @return
     */
    private AccountConfigurer accountConfigurer(String profile) {
        AccountConfigurer accountConfigurer = new AccountConfigurer();
        accountConfigurer.setApplicationContext(ContextUtils.getApplicationContext());
        Properties properties = new Properties();
        String configPath = "config/account-" + profile + ".properties";
        logger.info("***: " + configPath);
        try {
            properties.load(this.getClass().getClassLoader().getResourceAsStream(configPath));
        } catch (Throwable e) {
            throw new IllegalStateException("配置加载失败" + configPath);
        }
        accountConfigurer.initProperties(properties);
        return accountConfigurer;
    }
}
