package com.uas.ps.message.domain;

import java.io.Serializable;
import java.util.Date;
import java.util.Set;
import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.JoinTable;
import javax.persistence.ManyToMany;
import javax.persistence.OrderBy;
import javax.persistence.Table;
import org.hibernate.annotations.Cache;
import org.hibernate.annotations.CacheConcurrencyStrategy;

/**
 * 消息
 * Created by wangyc on 2018/1/13.
 *
 * @version 2018/1/13 11:26 wangyc
 */
@Entity
@Table(name = "messages")
public class Message implements Serializable {

    private static final long serialVersionUID = -1150575839820149569L;

    @Id
    @Column(name = "ms_id")
    @GeneratedValue(strategy = GenerationType.AUTO)
    private Long id;

    /**
     * 消息类型
     */
    @Column(name = "ms_type")
    private String type;

    /**
     * 消息内容
     */
    @Column(name = "ms_content")
    private String content;

    /**
     * 备注
     */
    @Column(name = "ms_remark")
    private String remark;

    /**
     * 消息来源id
     */
    @Column(name = "ms_sourceid")
    private Long sourceId;

    /**
     * 消息接受者json信息
     */
    @Column(name = "ms_receiver", columnDefinition = "TEXT")
    private String receiver;

    /**
     * 消息接收者uu
     */
    @Column(name = "ms_receiveruu")
    private Long receiverUu;

    /**
     * 消息接收者企业uu
     */
    @Column(name = "ms_receiverenuu")
    private Long receiverEnuu;

    /**
     * 消息发送者json信息
     */
    @Column(name = "ms_sender", columnDefinition = "TEXT")
    private String sender;

    /**
     * 消息发送者
     */
    @Column(name = "ms_senderuu")
    private Long senderUu;

    /**
     * 消息发送者企业uu
     */
    @Column(name = "ms_senderenuu")
    private Long senderEnuu;

    /**
     * 阅读状态
     * 1 已阅
     * 0 未读
     */
    @Column(name = "ms_isread")
    private Short isRead;

    /**
     * 来源应用id
     */
    @Column(name = "ms_producerApp")
    private Long producerApp;

    /**
     * 消费类型
     */
    @Column(name = "ms_consumeType")
    private String consumeType;

    /**
     * 生成时间
     */
    @Column(name = "ms_createTime")
    private Date createTime;

    /**
     * 推送方式类型
     */
    @Column(name = "ms_smsType")
    private String smsType;

    /**
     * 邮件模板id
     */
    @Column(name = "ms_mailtemplate")
    private String mailTemplate;

    /**
     * 短息模板id
     */
    @Column(name = "ms_smtemplate")
    private String smTemplate;

    /**
     * 是否已推送
     * 1 已阅
     * 0 未读
     */
    @Column(name = "ms_issent")
    private Short isSent;

    /**
     * 接收应用
     */
    @ManyToMany(cascade = { CascadeType.REFRESH, CascadeType.REMOVE }, fetch = FetchType.EAGER)
    @JoinTable(name = "message$consumeapp", joinColumns = @JoinColumn(name = "ms_id", referencedColumnName = "ms_id"), inverseJoinColumns = @JoinColumn(name = "app_id", referencedColumnName = "app_id"))
    @OrderBy("id")
    @Cache(usage = CacheConcurrencyStrategy.READ_WRITE)
    private Set<App> consumerApp;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }

    public Long getReceiverUu() {
        return receiverUu;
    }

    public void setReceiverUu(Long receiverUu) {
        this.receiverUu = receiverUu;
    }

    public Long getReceiverEnuu() {
        return receiverEnuu;
    }

    public void setReceiverEnuu(Long receiverEnuu) {
        this.receiverEnuu = receiverEnuu;
    }

    public String getReceiver() {
        return receiver;
    }

    public void setReceiver(String receiver) {
        this.receiver = receiver;
    }

    public Long getSenderUu() {
        return senderUu;
    }

    public void setSenderUu(Long senderUu) {
        this.senderUu = senderUu;
    }

    public Long getSenderEnuu() {
        return senderEnuu;
    }

    public void setSenderEnuu(Long senderEnuu) {
        this.senderEnuu = senderEnuu;
    }

    public String getSender() {
        return sender;
    }

    public void setSender(String sender) {
        this.sender = sender;
    }

    public Short getIsRead() {
        return isRead;
    }

    public void setIsRead(Short isRead) {
        this.isRead = isRead;
    }

    public Long getProducerApp() {
        return producerApp;
    }

    public void setProducerApp(Long producerApp) {
        this.producerApp = producerApp;
    }

    public String getConsumeType() {
        return consumeType;
    }

    public void setConsumeType(String consumeType) {
        this.consumeType = consumeType;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public String getSmsType() {
        return smsType;
    }

    public void setSmsType(String smsType) {
        this.smsType = smsType;
    }

    public String getMailTemplate() {
        return mailTemplate;
    }

    public void setMailTemplate(String mailTemplate) {
        this.mailTemplate = mailTemplate;
    }

    public String getSmTemplate() {
        return smTemplate;
    }

    public void setSmTemplate(String smTemplate) {
        this.smTemplate = smTemplate;
    }

    public Short getIsSent() {
        return isSent;
    }

    public void setIsSent(Short isSent) {
        this.isSent = isSent;
    }

    public Set<App> getConsumerApp() {
        return consumerApp;
    }

    public void setConsumerApp(Set<App> consumerApp) {
        this.consumerApp = consumerApp;
    }
}
