package com.uas.ps.message.service;

import com.uas.ps.core.page.PageParams;
import com.uas.ps.message.domain.Message;
import java.util.List;
import java.util.Map;
import org.springframework.data.domain.Page;
import org.springframework.ui.ModelMap;

/**
 * Created by wangyc on 2018/1/13.
 *
 * @version 2018/1/13 15:44 wangyc
 */
public interface MessageService {

    /**
     * 获取消息
     * @param receiverUu 收信人uu
     * @param receiverEnuu 收信人企业uu
     * @param consumerApp 接收app
     * @param pageParams 分页参数
     * @param isRead 读取状态
     * @param type 消息类型
     * @param keyword 关键词
     * @param pageParams
     * @return
     */
    Page<Message> getMessages(String receiverUu, String receiverEnuu, String consumerApp, String isRead, String type, String keyword, PageParams pageParams);

    /**
     * 获取未读消息数量
     * @param receiverUu 收信人uu
     * @param receiverEnuu 收信人企业uu
     * @param consumerApp 接收app
     * @return
     */
    Map<String, Object> getUnReadMessageCount(String receiverUu, String receiverEnuu, String consumerApp);

    /**
     * 获取未读消息数量
     * @param receiverUu 收信人uu
     * @param receiverEnuu 收信人企业uu
     * @param consumerApp 接收app
     * @param type 消息类型
     * @param isRead 阅读状态
     * @return
     */
    Map<String, Object> getMessageCount(String receiverUu, String receiverEnuu, String consumerApp, String type, String isRead);

    /**
     * 保存消息
     * @param messages 消息
     * @return
     */
    List<Message> saveMessages(String messages);

    /**
     * 推送消息
     * @param consumerApp 接收消息app
     * @return
     */
    Map<String, Object> sendMessage(String consumerApp);

    /**
     * 阅读消息
     * @param consumer 消息接收者信息
     * @return
     */
    ModelMap readMessage(String consumer);
}
